Credits

Subscribe for updates!

# Pyxie

Changelog
Open Source
Credits
Dev Status
Overview
Language Spec
Language Status
Project Status
Downloads, Links, etc
Arduino Profile

## Credits

This page aims to detail who is directly responsible for what, and where appropriate indirectly.

### Directly

Michael Sparks : sparks.m@gmail.com, blog, twitter, Linked in

- Implementation of Lexer, parser, code generation, AST, transforms, code generation, packaging etc
- Language spec
- Website design and implementation

Your name here: contact details

- What you've done/helped with

### Projects used by Pyxie (etc)

Listing key projects used here is a way of saying thank you :-)

David Beazley : for PLY - the python lex/yacc implementation used.

Updated: July 2015
Help, Contacts & Downloads
Copyright © 2016 Michael Sparks Open Source